From 821dea177e966fa8dceac19ae6ae4f03824ce58f Mon Sep 17 00:00:00 2001
From: JupiterRider <60042618+JupiterRider@users.noreply.github.com>
Date: Fri, 6 Dec 2024 20:58:24 +0100
Subject: [PATCH] IsWaveReady renamed
---
Raylib-cs/interop/Raylib.cs | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/Raylib-cs/interop/Raylib.cs b/Raylib-cs/interop/Raylib.cs
index ed1303c..a6d34cb 100644
--- a/Raylib-cs/interop/Raylib.cs
+++ b/Raylib-cs/interop/Raylib.cs
@@ -2698,9 +2698,9 @@ public static unsafe partial class Raylib
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern Wave LoadWaveFromMemory(sbyte* fileType, byte* fileData, int dataSize);
/// Checks if wave data is ready
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
- public static extern CBool IsWaveReady(Wave wave);
+ public static extern CBool IsWaveValid(Wave wave);
/// Load sound from file
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
@@ -2698,9 +2698,9 @@ public static unsafe partial class Raylib
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]
public static extern Wave LoadWaveFromMemory(sbyte* fileType, byte* fileData, int dataSize);
- /// Checks if wave data is ready
+ /// Checks if wave data is valid (data loaded and parameters)
[DllImport(NativeLibName, CallingConvention = CallingConvention.Cdecl)]